@@ -345,6 +345,26 @@ module APRS4R
     end
 
 
+    def latitude=( latitude)
+      logger.info( "latitude=( latitude)")
+
+      if has_position?
+        if is_mice?
+          # TODO: latitude= for MICEMessage
+        else
+          index = @@APRS_POSITION_LATITUDE_INDEX[type]
+          length = 8
+
+          if index + length < payload.length
+            payload[index...index+length] = APRSMessage.decimal2latitude( latitude)
+          end
+        end
+      end
+
+      return
+    end
+
+
     def longitude
       logger.info( "longitude")
 
@@ -368,6 +388,26 @@ module APRS4R
     end
 
     
+    def longitude=( longitude)
+      logger.info( "longitude=( longitude)")
+
+      if has_position?
+        if is_mice?
+          # TODO: longitude= for MICEMessage
+        else
+          index = @@APRS_POSITION_LONGITUDE_INDEX[type]
+          length = 8
+
+          if index + length < payload.length
+            payload[index...index+length] = APRSMessage.decimal2longitude( longitude)
+          end
+        end
+      end
+
+      return
+    end
+
+
     def has_extension?
       logger.info( "has_extension?")
 
@@ -788,7 +828,7 @@ module APRS4R
       return buffer.to_s
     end
 
-    
+
     def APRSMessage.degree2decimal( position)
       logger.info( "degree2decimal")
 
@@ -819,6 +859,80 @@ module APRS4R
     end
 
 
+    def APRSMessage.latitude2decimal( latitude)
+      logger.info( "latitude2decimal")
+
+      value = 0.0
+
+      if latitude.nil? || latitude.length < 8
+        return value
+      end
+
+      latitude_match = /^[\d\ ]{4}\.[\d\ ]{2}[NS]$/
+
+      if latitude =~ latitude_match
+        value = latitude[0...2].to_f + (latitude[2...4].to_f + latitude[5...7].to_f / 100.0) / 60.0
+        value *= -1.0 if latitude[7] == 'S'
+      end
+
+      return value
+    end
+
+
+    def APRSMessage.longitude2decimal( longitude)
+      logger.info( "longitude2decimal")
+
+      value = 0.0
+
+      if longitude.nil? || longitude.length < 9
+        return value
+      end
+
+      longitude_match = /^[\d\ ]{5}\.[\d\ ]{2}[EW]$/
+
+      if longitude =~ longitude_match
+        value = longitude[0...3].to_f + (longitude[3...5].to_f + longitude[6...8].to_f / 100.0) / 60.0
+        value *= -1.0 if longitude[8] == 'W'
+      end
+
+      return value
+    end
+
+
+    def APRSMessage.decimal2latitude( latitude)
+      logger.info( "decimal2latitude( latitude)")
+
+      degrees = latitude.abs.floor
+      print "degrees: #{degrees}\n"
+      minutes = (latitude.abs - degrees) * 60.0
+      print "minutes: #{minutes}\n"
+
+      orientation = 'N'
+      orientation = 'S' if latitude < 0.0
+      
+      value = sprintf( "%02.2i%02.2f%s", degrees, minutes, orientation)
+
+      return value
+    end
+
+
+    def APRSMessage.decimal2longitude( longitude)
+      logger.info( "decimal2longitude( longitude)")
+
+      degrees = longitude.abs.floor
+      print "degrees: #{degrees}\n"
+      minutes = (longitude.abs - degrees) * 60.0
+      print "minutes: #{minutes}\n"
+
+      orientation = 'E'
+      orientation = 'W' if longitude < 0.0
+      
+      value = sprintf( "%03.3i%02.2f%s", degrees, minutes, orientation)
+
+      return value
+    end
+
+
     def APRSMessage.APRS_PATH_RELAY
       return @@APRS_PATH_RELAY
     end
