@@ -31,7 +31,8 @@ module APRS4R
 
     @logger = APRS4RLogger.get_logger( "BeaconPlugin")
 
-
+    attr_reader :device, :period, :offset, :message
+    
     def initialize( configuration)
       logger.info( "initialize( configuration)")
 
@@ -62,11 +63,13 @@ module APRS4R
     def run
       logger.info( "run")
 
+      Thread.abort_on_exception = true
       sleep @offset
 
       while true
-        logger.debug( "sending beacon #{@message} on device #{@device}")
-        SocketManager.sendAPRSMessage( @device, @message)
+        message = create_beacon
+        logger.debug( "sending beacon #{message} on device #{@device}")
+        SocketManager.sendAPRSMessage( @device, message)
 
         sleep @period
       end
@@ -74,6 +77,14 @@ module APRS4R
       return
     end
 
+
+    def create_beacon
+      logger.info( "create_beacon")
+      
+      return @message
+    end
+
   end
 
+
 end
