@@ -226,7 +226,7 @@ module APRS4R
       if has_thermo? && payload.length >= 3
         temperature = high_nibble( payload[2] & 0x30) * 100.0 + low_nibble( payload[2]) * 10.0 + high_nibble( payload[1]) + low_nibble( payload[1]) / 10.0 
 
-        if payload[2].to_i & 0x80
+        if (payload[2].to_i & 0x80) == 0x80
           temperature *= -1.0
         end
       end
