@@ -33,6 +33,15 @@ module APRS4R
 
   class APRSMessageTest < Test::Unit::TestCase
 
+    def test_latitude2decimal
+      assert_equal( 0.0, APRSMessage.latitude2decimal( "0000.00N"))
+      assert_equal( 0.0, APRSMessage.latitude2decimal( "0000.00S"))
+    end
+
+    def test_longitude2decimal
+      assert_equal( 0.0, APRSMessage.longitude2decimal( "00000.00E"))
+      assert_equal( 0.0, APRSMessage.longitude2decimal( "00000.00W"))
+    end
 
     def test_degree2decimal_zero
       position1 = "0000.00N"
